darkhistory.electrons.ics.BE_integrals.F_x_log — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals.F_x_log

`darkhistory.electrons.ics.BE_integrals.` `F_x_log`(a, b, tol=1e-10)

  Definite integral of x log(x)/(exp(x) - 1).

  Parameters: | a : ndarray Lower limit of integration. b : ndarray Upper limit of integration. tol : float The relative tolerance to be reached.
  Returns: | float The resulting integral.

#### Previous topic

darkhistory.electrons.ics.BE_integrals.F_log_a

#### Next topic

darkhistory.electrons.ics.BE_integrals.F_x_log_a

### This Page

Show Source